%define module	setuptools
%define subrel 1
 
Summary:	Easily build and distribute Python packages
Name:		python-%{module}
Version:	1.3
Release:	%mkrel 1
License:	Python or ZPLv2.0
Group:		Development/Python
Url:		http://pypi.python.org/pypi/%{module}
Source0:	http://pypi.python.org/packages/source/s/%{module}/%{module}-%{version}.tar.gz
# Test data for the svn unittests from
# https://bitbucket.org/pypa/setuptools/src/ca2fc862ded7e3a2c07397f0d7d929a9534493a7/setuptools/tests/svn_data/svn17_example.zip?at=default
# Pull Request to add this to the next upstream release here: 
# https://github.com/jaraco/setuptools/pull/4
Source1:        svn17_example.zip
# https://bitbucket.org/pypa/setuptools/src/ca2fc862ded7e3a2c07397f0d7d929a9534493a7/setuptools/tests/svn_data/svn18_example.zip?at=default
Source2:        svn18_example.zip

BuildArch:	noarch
BuildRequires:	python-devel
BuildRequires:	python-backports-ssl_match_hostname
# For unittests
BuildRequires:	subversion

Requires:	python-pkg-resources

Provides:	python-setuptools-devel = %{version}-%{release}
Obsoletes:	python-setuptools-devel < 0.7

Provides:	python-distribute = %{version}-%{release}
Obsoletes:	python-distribute < 0.7

%description
A collection of enhancements to the Python distutils that allow 
you to more easily build and distribute Python packages, especially 
ones that have dependencies on other packages.


%package -n python3-%{module}
Summary:	Easily build and distribute Python3 packages
Group:		Development/Python

BuildRequires:	python3-devel
Requires:	python3-pkg-resources

Provides:	python3-setuptools-devel = %{version}-%{release}
Obsoletes:	python3-setuptools-devel < 0.7

Provides:	python3-distribute = %{version}-%{release}
Obsoletes:	python3-distribute < 0.7

%description -n python3-setuptools
A collection of enhancements to the Python 3 distutils that allow
you to more easily build and distribute Python 3 packages, especially
ones that have dependencies on other packages.


%package -n python-pkg-resources
Summary: Runtime module to access python resources
Group:		Development/Python

%description -n python-pkg-resources
Module used to find and manage Python package/version dependencies and access
bundled files and resources, including those inside of zipped .egg files.


%package -n python3-pkg-resources
Summary: Runtime module to access python 3 resources
Group:		Development/Python

%description -n python3-pkg-resources
Module used to find and manage Python 3 package/version dependencies and access
bundled files and resources, including those inside of zipped .egg files.


%prep
%setup -q -n %{module}-%{version}

find -name '*.txt' -exec chmod -x \{\} \;
find . -name '*.orig' -exec rm \{\} \;

# For unittests
cp %{SOURCE1} setuptools/tests/svn_data/
cp %{SOURCE2} setuptools/tests/svn_data/

rm -rf %{py3dir}
cp -a . %{py3dir}
pushd %{py3dir}
for file in setuptools/command/easy_install.py ; do
    sed -i '1s|^#!python|#!%{__python3}|' $file
done
popd

%build
CFLAGS="%{optflags}" %{__python} setup.py build

pushd %{py3dir}
CFLAGS="%{optflags}" %{__python3} setup.py build
popd

%install
# Must do the python3 install first because the scripts in /usr/bin are
# overwritten with every setup.py install (and we want the python2 version
# to be the default for now).
pushd %{py3dir}
%{__python3} setup.py install --skip-build --root %{buildroot}

rm -rf %{buildroot}%{python3_sitelib}/setuptools/tests

find %{buildroot}%{python3_sitelib} -name '*.exe' | xargs rm -f
chmod +x %{buildroot}%{python3_sitelib}/setuptools/command/easy_install.py
popd

%{__python} setup.py install --skip-build --root %{buildroot}

rm -rf %{buildroot}%{python_sitelib}/setuptools/tests

find %{buildroot}%{python_sitelib} -name '*.exe' | xargs rm -f
chmod +x %{buildroot}%{python_sitelib}/setuptools/command/easy_install.py

%check
%{__python} setup.py test

pushd %{py3dir}
%{__python3} setup.py test
popd

%files
%doc *.txt docs
%{_bindir}/easy_install
%{_bindir}/easy_install-2.*
%{python_sitelib}/*
%exclude %{python_sitelib}/pkg_resources.py*

%files -n python-pkg-resources
%{python_sitelib}/pkg_resources.py*

%files -n python3-setuptools
%doc *.txt docs
%{_bindir}/easy_install-3.*
%{python3_sitelib}/*
%exclude %{python3_sitelib}/pkg_resources.py*
%exclude %{python3_sitelib}/__pycache__/pkg_resources.cpython-*.py*

%files -n python3-pkg-resources
%{python3_sitelib}/pkg_resources.py*
%{python3_sitelib}/__pycache__/pkg_resources.cpython-*.py*



%changelog
* Thu Jul 17 2014 philippem <philippem> 1.3-1.1.mga4
+ Revision: 653495
- fix files list for python3

* Tue Nov 05 2013 philippem <philippem> 1.3-1.mga4
+ Revision: 549629
- Update to 1.3

* Tue Oct 22 2013 umeabot <umeabot> 1.1.6-3.mga4
+ Revision: 544250
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.1.6-2.mga4
+ Revision: 499362
- Rebuild to add different pythonegg provides for python 2 and 3

* Wed Sep 25 2013 philippem <philippem> 1.1.6-1.mga4
+ Revision: 486390
- Update to 1.1.6

* Sun Aug 25 2013 philippem <philippem> 1.0-1.mga4
+ Revision: 471705
- update to 1.0

* Wed Jul 17 2013 philippem <philippem> 0.9.5-1.mga4
+ Revision: 455199
- Update to 0.9.5
  - package_index can handle hashes other than md5
  - Fix security vulnerability in SSL certificate validation

* Thu Jul 11 2013 philippem <philippem> 0.8-1.mga4
+ Revision: 453030
- Update to the setuptools-0.8 branch that merges distribute and setuptools

* Sat Jun 08 2013 philippem <philippem> 0.6.45-1.mga4
+ Revision: 440665
- new upstream

* Fri Feb 08 2013 anssi <anssi> 0.6.28-6.mga3
+ Revision: 395526
- versionize Obsoletes to avoid any future issues

* Mon Feb 04 2013 spuhler <spuhler> 0.6.28-5.mga3
+ Revision: 394464
- added Obsoletes: python-distribute

* Sat Jan 26 2013 dmorgan <dmorgan> 0.6.28-4.mga3
+ Revision: 392538
- Rebuild to add missing rpm

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Sep 29 2012 fwang <fwang> 0.6.28-2.mga3
+ Revision: 300324
- rebuild for new py3.3

* Mon Aug 13 2012 lebedov <lebedov> 0.6.28-1.mga3
+ Revision: 281173
- Update to 0.6.28.

* Mon Mar 12 2012 kamil <kamil> 0.6.24-2.mga2
+ Revision: 223161
- python 3 build
- update license (according to Fedora)

* Wed Oct 26 2011 philippem <philippem> 0.6.24-1.mga2
+ Revision: 158282
- Upstream bugfix release 0.6.24

* Sun Jun 19 2011 kharec <kharec> 0.6.19-1.mga2
+ Revision: 109701
- new version 0.6.19

* Fri Feb 18 2011 ahmad <ahmad> 0.6.14-7.mga1
+ Revision: 53912
- rebuild so that the pythonegg autoprovides become available

* Mon Jan 17 2011 pterjan <pterjan> 0.6.14-6.mga1
+ Revision: 21275
- Rebuild for python 2.7

* Sun Jan 09 2011 blino <blino> 0.6.14-5.mga1
+ Revision: 3687
- remove old conflicts
- imported package python-setuptools

